aboutsummaryrefslogtreecommitdiff
path: root/sound/wave.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'sound/wave.cpp')
-rw-r--r--sound/wave.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/sound/wave.cpp b/sound/wave.cpp
index 1d0ec2916e..e3e5fc2daf 100644
--- a/sound/wave.cpp
+++ b/sound/wave.cpp
@@ -105,8 +105,8 @@ bool loadWAVFromStream(Common::SeekableReadStream &stream, int &size, int &rate,
flags = 0;
if (bitsPerSample == 8) // 8 bit data is unsigned
flags |= SoundMixer::FLAG_UNSIGNED;
- else if (bitsPerSample == 16) // 16 bit data is signed
- flags |= SoundMixer::FLAG_16BITS;
+ else if (bitsPerSample == 16) // 16 bit data is signed little endian
+ flags |= (SoundMixer::FLAG_16BITS | SoundMixer::FLAG_LITTLE_ENDIAN);
else {
warning("getWavInfo: unsupported bitsPerSample %d", bitsPerSample);
return false;